@@ -90,10 +90,10 @@
 	}
 
 	function removeWidgetInfoBtns($content_header) {
-		if ($content_header.find('[data-hintbox=1]').length) {
-			$content_header.find('[data-hintbox=1]').next('.hint-box').remove();
-			$content_header.find('[data-hintbox=1]').trigger('remove');
-		}
+		$content_header.find('[data-hintbox=1]')
+			.trigger('remove')
+			.next('.hint-box')
+			.remove();
 	}
 
 	function resizeDashboardGrid($obj, data, min_rows) {
@@ -434,7 +434,12 @@
 	function startWidgetRefreshTimer($obj, data, widget, rf_rate) {
 		if (rf_rate != 0) {
 			widget['rf_timeoutid'] = setTimeout(function () {
-				if (doAction('timer_refresh', $obj, data, widget) == 0) {
+				// Do not update widget content if there are active popup or hintbox.
+				var active = widget['content_body'].find('[data-expanded="true"]');
+
+				widget['div'][active.length ? 'addClass' : 'removeClass']('dashbrd-grid-widget-no-refresh');
+
+				if (active.length == 0 && doAction('timer_refresh', $obj, data, widget) == 0) {
 					// widget was not updated, update it's content
 					updateWidgetContent($obj, data, widget);
 				}
@@ -503,7 +508,8 @@
 			dataType: 'json',
 			success: function(resp) {
 				stopPreloader(widget);
-				var $content_header = $('h4', widget['content_header']);
+				var $content_header = $('h4', widget['content_header']),
+					debug_visible = $('[name="zbx_debug_info"]', widget['content_body']).is(':visible');
 
 				$content_header.text(resp.header);
 
@@ -511,14 +517,13 @@
 					$content_header.attr('aria-label', (resp.aria_label !== '') ? resp.aria_label : null);
 				}
 
-				widget['content_body'].find('[data-hintbox=1]').trigger('remove');
 				widget['content_body'].empty();
 				if (typeof(resp.messages) !== 'undefined') {
 					widget['content_body'].append(resp.messages);
 				}
 				widget['content_body'].append(resp.body);
 				if (typeof(resp.debug) !== 'undefined') {
-					widget['content_body'].append(resp.debug);
+					$(resp.debug).appendTo(widget['content_body'])[debug_visible ? 'show' : 'hide']();
 				}
 				removeWidgetInfoBtns(widget['content_header']);
 
@@ -528,19 +533,6 @@
 
 				// Creates new script elements and removes previous ones to force their re-execution.
 				widget['content_script'].empty();
-				if (typeof(resp.script_file) !== 'undefined' && resp.script_file.length) {
-					// NOTE: it is done this way to make sure, this script is executed before script_run function below.
-					if (typeof(resp.script_file) === 'string') {
-						resp.script_file = [resp.script_file];
-					}
-
-					for (var i = 0, l = resp.script_file.length; l > i; i++) {
-						var new_script = $('<script>')
-							.attr('type', 'text/javascript')
-							.attr('src', resp.script_file[i]);
-						widget['content_script'].append(new_script);
-					}
-				}
 				if (typeof(resp.script_inline) !== 'undefined') {
 					// NOTE: to execute script with current widget context, add unique ID for required div, and use it in script.
 					var new_script = $('<script>')
@@ -671,6 +663,7 @@
 
 						widget['header'] = name;
 						widget['fields'] = fields;
+						doAction('afterUpdateWidgetConfig', $obj, data, null);
 						updateWidgetDynamic($obj, data, widget);
 						refreshWidget($obj, data, widget);
 					}
@@ -793,7 +786,6 @@
 		var index = widget['div'].data('widget-index');
 
 		// remove div from the grid
-		widget['div'].find('[data-hintbox=1]').trigger('remove');
 		widget['div'].remove();
 		data['widgets'].splice(index, 1);
 
@@ -1043,11 +1035,11 @@
 				'max-columns': 12,
 				'rows': 0,
 				'updated': false,
-				'editable': true
+				'editable': true,
+				'edit_mode': false
 			};
 			options = $.extend(default_options, options);
 			options['widget-width'] = 100 / options['max-columns'];
-			options['edit_mode'] = false;
 
 			return this.each(function() {
 				var	$this = $(this),
